%% ``The contents of this file are subject to the Erlang Public License,
%% Version 1.1, (the "License"); you may not use this file except in
%% compliance with the License. You should have received a copy of the
%% Erlang Public License along with this software. If not, it can be
%% retrieved via the world wide web at http://www.erlang.org/.
%% 
%% Software distributed under the License is distributed on an "AS IS"
%% basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
%% the License for the specific language governing rights and limitations
%% under the License.
%% 
%% The Initial Developer of the Original Code is Ericsson Utvecklings AB.
%% Portions created by Ericsson are Copyright 1999, Ericsson Utvecklings
%% AB. All Rights Reserved.''
%% 
%%     $Id$
%%
-module(erl.lang.node).

-export([is_alive/0, monitor/2, node/0, node/1, nodes/0, nodes/1,
	 ports/0, processes/0, register/2, registered/0, timestamp/0,
	 unregister/1, whereis/1]).


%% @doc Returns a list of all visible nodes in the system, excluding the
%% current node.
%% @equiv nodes(visible)

nodes() -> erl.lang.node:nodes(visible).


%% @doc Returns a unique timestamp <code>{Node,Now}</code>.
%% <code>Node</code> is the current node and <code>Now</code> is the
%% result from calling {@link erl.system:now/0}.

timestamp() -> {erl.lang.node:node(),erl.system:now()}.


%% @doc Returns <code>true</code> if the current node is alive; i.e., if
%% the node can be part of a distributed system, otherwise returns
%% <code>false</code>.

is_alive() ->
    erl.lang.node:is_alive().    % Built-in function


%% @doc See {@link /kernel/erlang:monitor_node/2}.
monitor(Node, Flag) ->
    erl.lang.node:monitor(Node, Flag).    % Built-in function


%% @doc Returns the name of the current node. If it is not a networked
%% node but a local Erlang runtime system, the atom
%% <code>nonode@nohost</code> is returned.

node() ->
    erl.lang.node:node().    % Built-in function


%% @doc Returns the node where <code>Object</code> is
%% located. <code>Object</code> can be a pid, a reference, or a port.

node(Object) ->
    erl.lang.node:node(Object).    % Built-in function


%% @doc See {@link /kernel/erlang:nodes/1}.
nodes(Arg) ->
    erl.lang.node:nodes(Arg).    % Built-in function


%% @doc Returns a list of all ports on the current node.

ports() ->
    erl.lang.node:ports().    % Built-in function


%% @doc Returns a list of all processes on the current node.

processes() ->
    erl.lang.node:processes().    % Built-in function


%% @doc Associates a name with a port or process. <code>Name</code>,
%% which must be an atom, can then be used instead of a port or pid in
%% the <code>!</code> (send) operator, as in <code>Name !
%% Message</code>.
%%
%% <p>Returns <code>true</code>. FIXME: should return <code>ok</code>!</p>

register(Name, Object) ->
    erl.lang.node:register(Name, Object).    % Built-in function


%% @doc Returns a list of registered names on the current node.
%% @see register/2

registered() ->
    erl.lang.node:registered().    % Built-in function


%% @doc Removes a registered name on the current node.
%%
%% <p>Returns <code>true</code>. FIXME: should return <code>ok</code>!</p>
%%
%% @see register/2

unregister(Name) ->
    erl.lang.node:unregister(Name).    % Built-in function


%% @doc Returns the identifier of the port or process registered under a
%% given name on the current node. Returns <code>undefined</code> if no
%% such name is registered.
%%
%% @see register/2

whereis(Name) ->
    erl.lang.node:whereis(Name).    % Built-in function
